﻿using System;
using System.IO;
using System.Net;
using System.Threading.Tasks;

namespace Katteker
{
    public static class ChangelogHelper
    {
        private static string GenerateChangelogAsHtml(string text, string extension)
        {
            string result;
            switch (extension)
            {
                case ".txt":
                    var plainText = WebUtility.HtmlEncode(text);
                    result = plainText.Replace(Environment.NewLine, "<br />");
                    break;
                case ".md":
                    result = new MarkdownSharp.Markdown().Transform(text);
                    break;
                default:
                    result = text;
                    break;
            }

            return result;
        }

        public static async Task<string> LoadChangelogAsync(string filename, string path)
        {
            if (!string.IsNullOrEmpty(filename) || !string.IsNullOrEmpty(path))
            {
                if (!path.EndsWith("/", StringComparison.Ordinal))
                    path += "/";
                var webReq = WebRequest.Create(path + filename);
                try
                {
                    using (var response = await webReq.GetResponseAsync().ConfigureAwait(false))
                    using (var sr = new StreamReader(response.GetResponseStream()))
                    {
                        return GenerateChangelogAsHtml(await sr.ReadToEndAsync().ConfigureAwait(false),
                            Path.GetExtension(filename));
                    }
                }
                catch (WebException)
                {
                    var changelogFilename = Path.GetFileName(filename);
                    if (changelogFilename == null) return GenerateChangelogAsHtml("Changelog not found", ".txt");
                    var currentChangelogPath = Path.Combine(Environment.CurrentDirectory, changelogFilename);
                    if (File.Exists(currentChangelogPath))
                    {
                        return GenerateChangelogAsHtml(File.ReadAllText(currentChangelogPath), Path.GetExtension(filename));
                    }
                }
            }

            return GenerateChangelogAsHtml("Changelog not found", ".txt");
        }
    }
}