﻿using System;
using System.Reflection;

namespace Katteker
{
    /// <summary>
    /// Extension methods for the App-Version.
    /// </summary>
    public static class VersionExtension
    {
        /// <summary>
        /// Get the current Version of Application.
        /// </summary>
        public static SemanticVersion GetCurrentVersion
        {
            get
            {
                var assemblyVersion = Assembly.GetEntryAssembly().GetName().Version.ToString(3);
                var getCurrentVersion = SemanticVersion.Parse(assemblyVersion);
                var informalVersion = Assembly.GetEntryAssembly().GetCustomAttribute<AssemblyInformationalVersionAttribute>()?.InformationalVersion;
                if (informalVersion != null && SemanticVersion.TryParse(informalVersion, out var semVersion))
                    return semVersion;
                return getCurrentVersion;
            }
        }

        public static Version ToSystemVersion(this SemanticVersion value) => new Version(value.Major, value.Minor, value.Patch, 0);

        /// <summary>
        /// Get the current Version of Application.
        /// </summary>
        public static string GetFullVersion => GetCurrentVersion.ToString();
    }
}